<?php
/*
 * Local plugin enable/disable settings
 *
 * Auto-generated by install script
 * Date: [[reg_date]]
 */

$plugins['authad']    = 0;
$plugins['authldap']  = 0;
$plugins['authmysql'] = 0;
$plugins['authpgsql'] = 0;
